=============
Release Notes
=============
.. toctree::
    :maxdepth: 1

    release/release-2.9
    release/release-2.6
    release/release-2.3
    release/release-2.2
    release/release-2.1
    release/release-2.0
    release/release-1.5
    release/release-1.4
    release/release-1.3
    release/release-1.2
    release/release-1.1
    release/release-0.1.0
